pub enum Mode {
AllBinary(bool),
BlobsDescriptions(bool),
AllDescriptions(bool),
SomeBlobsBinary(FieldIdSet),
SomeBinary(FieldIdSet),
}Variants
AllBinary(bool)
All blobs read as binary
BlobsDescriptions(bool)
Blobs as descriptions, other binary as binary (default)
AllDescriptions(bool)
All binary columns as descriptions
SomeBlobsBinary(FieldIdSet)
Specific blobs read as binary, rest as descriptions (non-blob binary stays binary)
SomeBinary(FieldIdSet)
Specific columns as binary, all other binary as descriptions
Implementations
Sourceimpl Mode
impl Mode
Sourcepub fn merge(
field: &mut Option<Mode>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Mode>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.