pub struct FilteredReadOptionsProto {Show 14 fields
pub scan_range_before_filter: Option<U64Range>,
pub scan_range_after_filter: Option<U64Range>,
pub with_deleted_rows: bool,
pub batch_size: Option<u32>,
pub fragment_readahead: Option<u64>,
pub fragment_ids: Vec<u64>,
pub projection: Option<ProjectionProto>,
pub refine_filter_substrait: Option<Vec<u8>>,
pub full_filter_substrait: Option<Vec<u8>>,
pub threading_mode: Option<FilteredReadThreadingModeProto>,
pub io_buffer_size_bytes: Option<u64>,
pub filter_schema_ipc: Option<Vec<u8>>,
pub materialization_readahead_bytes: Option<u64>,
pub batch_size_bytes: Option<u64>,
}Expand description
Serializable form of FilteredReadOptions.
Fields
scan_range_before_filter: Option<U64Range>scan_range_after_filter: Option<U64Range>with_deleted_rows: boolbatch_size: Option<u32>fragment_readahead: Option<u64>fragment_ids: Vec<u64>projection: Option<ProjectionProto>refine_filter_substrait: Option<Vec<u8>>full_filter_substrait: Option<Vec<u8>>threading_mode: Option<FilteredReadThreadingModeProto>io_buffer_size_bytes: Option<u64>filter_schema_ipc: Option<Vec<u8>>Arrow IPC schema for decoding Substrait filters (may be wider than projection).
materialization_readahead_bytes: Option<u64>If present, a nonzero upper bound on bytes reserved by Blob v2 materialization awaiting ordered emission in one scanner execution. Admission follows output order; one oversized output batch may exceed the bound when no other batch is reserved. If absent, Blob v2 materialization has no independent memory bound.
batch_size_bytes: Option<u64>If present, the scanner-level byte budget for output batches. When set, the file reader uses it as an additional batch boundary alongside the row-based batch_size. This corresponds to FileReaderOptions.batch_size_bytes.
Implementations
Sourceimpl FilteredReadOptionsProto
impl FilteredReadOptionsProto
Sourcepub fn batch_size(&self) -> u32
pub fn batch_size(&self) -> u32
Returns the value of batch_size, or the default value if batch_size is unset.
Sourcepub fn fragment_readahead(&self) -> u64
pub fn fragment_readahead(&self) -> u64
Returns the value of fragment_readahead, or the default value if fragment_readahead is unset.
Sourcepub fn refine_filter_substrait(&self) -> &[u8] ⓘ
pub fn refine_filter_substrait(&self) -> &[u8] ⓘ
Returns the value of refine_filter_substrait, or the default value if refine_filter_substrait is unset.
Sourcepub fn full_filter_substrait(&self) -> &[u8] ⓘ
pub fn full_filter_substrait(&self) -> &[u8] ⓘ
Returns the value of full_filter_substrait, or the default value if full_filter_substrait is unset.
Sourcepub fn io_buffer_size_bytes(&self) -> u64
pub fn io_buffer_size_bytes(&self) -> u64
Returns the value of io_buffer_size_bytes, or the default value if io_buffer_size_bytes is unset.
Sourcepub fn filter_schema_ipc(&self) -> &[u8] ⓘ
pub fn filter_schema_ipc(&self) -> &[u8] ⓘ
Returns the value of filter_schema_ipc, or the default value if filter_schema_ipc is unset.
Sourcepub fn materialization_readahead_bytes(&self) -> u64
pub fn materialization_readahead_bytes(&self) -> u64
Returns the value of materialization_readahead_bytes, or the default value if materialization_readahead_bytes is unset.
Sourcepub fn batch_size_bytes(&self) -> u64
pub fn batch_size_bytes(&self) -> u64
Returns the value of batch_size_bytes, or the default value if batch_size_bytes is unset.