Module spill

Module spill 

Structs

SpillReceiver
SpillSender
The sender side of the spill. This is used to write batches to the spill.

Functions

create_replay_spill
Start a spill of Arrow data to a file that can be read later multiple times.
spilling_table_provider
Wrap a one-shot SendableRecordBatchStream in a re-scannable TableProvider.