pub trait DataFrameExt {
// Required method
fn group_by_stream<'life0, 'life1, 'async_trait>(
self,
partition_columns: &'life0 [&'life1 str],
) -> Pin<Box<dyn Future<Output = DFResult<BatchStreamGrouper>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Required Methods
Sourcefn group_by_stream<'life0, 'life1, 'async_trait>(
self,
partition_columns: &'life0 [&'life1 str],
) -> Pin<Box<dyn Future<Output = DFResult<BatchStreamGrouper>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn group_by_stream<'life0, 'life1, 'async_trait>(
self,
partition_columns: &'life0 [&'life1 str],
) -> Pin<Box<dyn Future<Output = DFResult<BatchStreamGrouper>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Execute the query and return as a grouped stream.
The data is assumed to have already been sorted by the partition columns.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".