Structs
- Spill
Receiver - Spill
Sender - The sender side of the spill. This is used to write batches to the spill.
Functions
- create_
replay_ spill - Start a spill of Arrow data to a file that can be read later multiple times.
- spilling_
table_ provider - Wrap a one-shot
SendableRecordBatchStreamin a re-scannableTableProvider.